;
var __SHWebViewStartTime__ = Date.now();
(function(global) {
    if (global.StockJSBridge) return;
    var isWebView = global.hasOwnProperty("document");
    var u = navigator.userAgent;
    var isAndroid = u.indexOf('Android') > -1 || u.indexOf('Adr') > -1; //android终端
    var index = 0;
    var invokeMap = {};
    var publishMap = {};
    var requestMap ={};

    /**
     * 与Native通讯
     * @param {String} eventName 事件名称
     * @param {bject} params 通讯数据
     * @param {String} target 回调id
     */

    var invokeHandler = function(eventName, params, target) {
        if (isWebView && !isAndroid) {
            global.webkit.messageHandlers.invokeHandler.postMessage({
                event: eventName,
                paramsString: params,
                callbackId: target
            });
        } else {
            var handlerData = StockJSCore.invokeHandler(eventName, params, target);
            if (void 0 !== handlerData && "" !== handlerData) {
                try {
                    handlerData = JSON.parse(handlerData);
                } catch (err) {
                    handlerData = {};
                }
                invokeMap[target](handlerData);
                delete invokeMap[target];
            }
        }
    };

    /**
     * webview通讯
     * @param {String} eventName 事件名称
     * @param {String} params 通讯数据
     * @param {String} target 通知目标对象
     */
    var publishHandler = function(eventName, params, target) {
        if (isWebView && !isAndroid) {
            global.webkit.messageHandlers.publishHandler.postMessage({
                event: eventName,
                paramsString: params,
                webviewIds: target
            });
        } else {
            StockJSCore.publishHandler(eventName, params, target);
        }
    };

    var invoke = function(eventName, params, callback) {
        var paramsString = JSON.stringify(params || {});
        var id = ++index;
        invokeMap[id] = callback;
        invokeHandler(eventName, paramsString, id);
    }
    var invokeCallbackHandler = function(eventName, params) {
        var fn = invokeMap[eventName];
        if (typeof(fn) === "function") {
            fn(params);
        }
        delete invokeMap[eventName];
    }
    var on = function(eventName, callback) {
        publishMap[eventName] = callback;
    }

    var publish = function(eventName, params, target) {
        target = target || [], target = JSON.stringify(target);
        var paramsString = JSON.stringify(params || {});
        eventName = "custom_event_" + eventName;
        publishHandler(eventName, paramsString, target);
    }

    var subscribe = function(eventName, callback) {
        invokeMap["custom_event_" + eventName] = callback;
    }

    var subscribeHandler = function(eventName, params) {
        var fn;
        if (eventName.indexOf("custom_event_") != -1) {
            fn = invokeMap[eventName];
        } else {
            fn = publishMap[eventName];
        }
        if ("function" === typeof(fn)) {
            fn(params);
        }
    }

    var request = function ( options ) {
        console.log('request Native:', options);
        StockJSBridge.invoke('createRequestTask',options,function(res){
            requestMap[res.requestTaskId] =options;
        });
        StockJSBridge.on('onRequestTaskStateChange', function(res) {
            res.data = JSON.parse(res.data);
            requestMap[res.requestTaskId].success(res)
            console.log(res);
        })
    }
    var StockJSBridge = {
        invoke: invoke,
        invokeCallbackHandler: invokeCallbackHandler,
        on: on,
        publish: publish,
        subscribe: subscribe,
        subscribeHandler: subscribeHandler,
        request: request,
        navigateTo: function(options) {
            this.invoke('navigateTo', options, function(res) {
                console.log(res);
            })
        },
        setTitle: function(title){
            this.invoke('setTitle', {title: title})
        },
        setFunctionButton: function(text){
            this.invoke('setFunctionButton', {text: text})
        },
        enablePullDownRefresh: function(flag){
            this.invoke('enablePullDownRefresh', {enabled: flag})
        },
        stopPullDownRefresh: function(flag){
            this.invoke("stopPullDownRefresh");
        }

    };
    global.shy = global.StockJSBridge = StockJSBridge;

    
})(this);

var nodeId = 0;
function changeNodeID(param) {
    nodeId = param;
    return "SHWebViewjs_changeNodeID_return" + nodeId;
}

var __SHWebViewEndTime__ = Date.now();